@@ -207,7 +207,7 @@ class OrderEnforcingWrapper(BaseWrapper):
         '''
         if value == "agent_order":
             raise AttributeError("agent_order has been removed from the API. Please consider using agent_iter instead.")
-        if value in {"rewards", "dones", "infos", "agent_selection"}:
+        elif value in {"rewards", "dones", "infos", "agent_selection"}:
             EnvLogger.error_field_before_reset(value)
             return None
         else:
